@@ -65,7 +65,7 @@ def do_lock(
             reporter = project.get_reporter(requirements, tracked_names, spin)
             resolver: Resolver = project.core.resolver_class(provider, reporter)
             try:
-                mapping, dependencies, summaries = resolve(
+                mapping, dependencies = resolve(
                     resolver,
                     requirements,
                     project.environment.python_requires,
@@ -86,7 +86,7 @@ def do_lock(
                 ui.echo(format_resolution_impossible(err), err=True)
                 raise
             else:
-                data = format_lockfile(mapping, dependencies, summaries)
+                data = format_lockfile(mapping, dependencies)
                 spin.succeed(f"{termui.Emoji.LOCK} Lock successful")
 
     project.write_lockfile(data, write=not dry_run)
@@ -181,6 +181,7 @@ def do_add(
     unconstrained: bool = False,
     no_editable: bool = False,
     no_self: bool = False,
+    dry_run: bool = False,
 ) -> None:
     """Add packages and install"""
     check_project_file(project)
@@ -207,12 +208,13 @@ def do_add(
             req.specifier = get_specifier("")
     group_deps.update(requirements)
     reqs = [r for deps in all_dependencies.values() for r in deps.values()]
-    resolved = do_lock(project, strategy, tracked_names, reqs)
+    resolved = do_lock(project, strategy, tracked_names, reqs, dry_run=dry_run)
 
     # Update dependency specifiers and lockfile hash.
     deps_to_update = group_deps if unconstrained else requirements
     save_version_specifiers({group: deps_to_update}, resolved, save)
-    project.add_dependencies(deps_to_update, group, dev)
+    if not dry_run:
+        project.add_dependencies(deps_to_update, group, dev)
     lockfile = project.lockfile
     project.write_lockfile(lockfile, False)
 
@@ -223,6 +225,8 @@ def do_add(
             default=False,
             no_editable=no_editable,
             no_self=no_self,
+            requirements=list(group_deps.values()),
+            dry_run=dry_run,
         )
 
 
@@ -238,6 +242,7 @@ def do_update(
     top: bool = False,
     dry_run: bool = False,
     packages: Sequence[str] = (),
+    sync: bool = True,
     no_editable: bool = False,
     no_self: bool = False,
 ) -> None:
@@ -294,18 +299,21 @@ def do_update(
         reqs,
         dry_run=dry_run,
     )
-    do_sync(
-        project,
-        groups=groups,
-        dev=install_dev,
-        default=default,
-        clean=False,
-        dry_run=dry_run,
-        requirements=[r for deps in updated_deps.values() for r in deps.values()],
-        tracked_names=list(chain.from_iterable(updated_deps.values())) if top else None,
-        no_editable=no_editable,
-        no_self=no_self,
-    )
+    if sync:
+        do_sync(
+            project,
+            groups=groups,
+            dev=install_dev,
+            default=default,
+            clean=False,
+            dry_run=dry_run,
+            requirements=[r for deps in updated_deps.values() for r in deps.values()],
+            tracked_names=list(chain.from_iterable(updated_deps.values()))
+            if top
+            else None,
+            no_editable=no_editable,
+            no_self=no_self,
+        )
     if unconstrained and not dry_run:
         # Need to update version constraints
         save_version_specifiers(updated_deps, resolved, save)
@@ -323,6 +331,7 @@ def do_remove(
     packages: Sequence[str] = (),
     no_editable: bool = False,
     no_self: bool = False,
+    dry_run: bool = False,
 ) -> None:
     """Remove packages from working set and pyproject.toml"""
     check_project_file(project)
@@ -352,8 +361,9 @@ def do_remove(
         for i in matched_indexes:
             del deps[i]
 
-    project.write_pyproject()
-    do_lock(project, "reuse")
+    if not dry_run:
+        project.write_pyproject()
+    do_lock(project, "reuse", dry_run=dry_run)
     if sync:
         do_sync(
             project,
@@ -362,6 +372,7 @@ def do_remove(
             clean=True,
             no_editable=no_editable,
             no_self=no_self,
+            dry_run=dry_run,
         )
 
 
